@@ -36,18 +36,14 @@ impl Args {
         let env = match env::var(OPTS_ENV_VAR) {
             Ok(var) => {
                 let Some(mut opts) = shlex::split(&var) else {
-                    anyhow::bail!("String in `{}` environment variable cannot be parsed as a shell command: {:?}", OPTS_ENV_VAR, var);
+                    anyhow::bail!("String in `{OPTS_ENV_VAR}` environment variable cannot be parsed as a shell command: {var:?}");
                 };
                 opts.reverse();
                 opts
             }
             Err(env::VarError::NotPresent) => vec![],
             Err(env::VarError::NotUnicode(invalid)) => {
-                anyhow::bail!(
-                    "String in `{}` environment variable is not a valid UTF-8 sequence: {:?}",
-                    OPTS_ENV_VAR,
-                    invalid,
-                );
+                anyhow::bail!("String in `{OPTS_ENV_VAR}` environment variable is not a valid UTF-8 sequence: {invalid:?}");
             }
         };
 
@@ -87,6 +83,7 @@ fn command() -> Command {
             For more details, visit https://github.com/rhysd/hgrep#readme"
         )
         .no_binary_name(true)
+        .args_override_self(true)
         .arg(
             Arg::new("min-context")
                 .short('c')
@@ -415,6 +412,13 @@ fn command() -> Command {
                     .value_name("NUM+SUFFIX?")
                     .help("The upper size limit of the regex DFA. The default limit is 10M. For the size suffixes, see --max-filesize"),
             )
+            .arg(
+                Arg::new("unrestricted")
+                    .short('u')
+                    .long("unrestricted")
+                    .action(ArgAction::Count)
+                    .help(r#"Reduce the level of "smart" filtering by repeated uses (up to 2). A single flag is equivalent to --no-ignore. Two flags are equivalent to --no-ignore --hidden. Unlike ripgrep, three flags are not supported since hgrep doesn't support --binary flag"#)
+            )
             .arg(
                 Arg::new("PATTERN")
                     .help("Pattern to search. Regular expression is available"),
@@ -488,33 +492,33 @@ fn build_ripgrep_config(
     if let Some(num) = matches.get_one::<String>("max-count") {
         let num = num
             .parse()
-            .context("could not parse --max-count option value as unsigned integer")?;
+            .context("Could not parse --max-count option value as unsigned integer")?;
         config.max_count(num);
     }
 
     if let Some(num) = matches.get_one::<String>("max-depth") {
         let num = num
             .parse()
-            .context("could not parse --max-depth option value as unsigned integer")?;
+            .context("Could not parse --max-depth option value as unsigned integer")?;
         config.max_depth(num);
     }
 
     if let Some(size) = matches.get_one::<String>("max-filesize") {
         config
             .max_filesize(size)
-            .context("could not parse --max-filesize option value as file size string")?;
+            .context("Could not parse --max-filesize option value as file size string")?;
     }
 
     if let Some(limit) = matches.get_one::<String>("regex-size-limit") {
         config
             .regex_size_limit(limit)
-            .context("could not parse --regex-size-limit option value as size string")?;
+            .context("Could not parse --regex-size-limit option value as size string")?;
     }
 
     if let Some(limit) = matches.get_one::<String>("dfa-size-limit") {
         config
             .dfa_size_limit(limit)
-            .context("could not parse --dfa-size-limit option value as size string")?;
+            .context("Could not parse --dfa-size-limit option value as size string")?;
     }
 
     let types = matches.get_many::<String>("type");
@@ -527,6 +531,17 @@ fn build_ripgrep_config(
         config.types_not(types_not.map(String::as_str));
     }
 
+    match matches.get_count("unrestricted") {
+        0 => {}
+        1 => {
+            config.no_ignore(true);
+        }
+        2 => {
+            config.no_ignore(true).hidden(true);
+        }
+        _ => anyhow::bail!("-u or --unrestricted cannot be repeated more than twice. Try -uu to search every text file"),
+    }
+
     Ok(config)
 }
 
@@ -569,19 +584,19 @@ fn run(matches: ArgMatches) -> Result<bool> {
         .get_one::<String>("min-context")
         .unwrap()
         .parse()
-        .context("could not parse \"min-context\" option value as unsigned integer")?;
+        .context("Could not parse \"min-context\" option value as unsigned integer")?;
     let max_context = matches
         .get_one::<String>("max-context")
         .unwrap()
         .parse()
-        .context("could not parse \"max-context\" option value as unsigned integer")?;
+        .context("Could not parse \"max-context\" option value as unsigned integer")?;
     let max_context = cmp::max(min_context, max_context);
 
     let mut printer_opts = PrinterOptions::default();
     if let Some(width) = matches.get_one::<String>("tab") {
         printer_opts.tab_width = width
             .parse()
-            .context("could not parse \"tab\" option value as unsigned integer")?;
+            .context("Could not parse \"tab\" option value as unsigned integer")?;
     }
 
     #[cfg(feature = "bat-printer")]
@@ -614,7 +629,7 @@ fn run(matches: ArgMatches) -> Result<bool> {
     if let Some(width) = matches.get_one::<String>("term-width") {
         let width = width
             .parse()
-            .context("could not parse \"term-width\" option value as unsigned integer")?;
+            .context("Could not parse \"term-width\" option value as unsigned integer")?;
         printer_opts.term_width = width;
         if width < 10 {
             anyhow::bail!("Too small value at --term-width option ({} < 10)", width);
@@ -747,10 +762,7 @@ fn run(matches: ArgMatches) -> Result<bool> {
 fn main() {
     #[cfg(windows)]
     if let Err(code) = nu_ansi_term::enable_ansi_support() {
-        eprintln!(
-            "ANSI color support could not be enabled with error code {}",
-            code
-        );
+        eprintln!("ANSI color support could not be enabled with error code {code}");
         process::exit(2);
     }
 
@@ -806,7 +818,7 @@ mod tests {
                     settings.set_snapshot_path(SNAPSHOT_DIR);
                     settings.bind(|| {
                         let cmd = command();
-                        let mat = cmd.get_matches_from($args);
+                        let mat = cmd.try_get_matches_from($args).unwrap();
                         let raw = get_raw_matched_arguments(&mat);
                         insta::assert_debug_snapshot!(raw);
                     });
@@ -839,6 +851,10 @@ mod tests {
             ["--generate-completion-script", "bash"]
         );
         snapshot_test!(generate_man_page, ["--generate-man-page"]);
+        snapshot_test!(max_filesize, ["--max-filesize", "100M"]);
+        snapshot_test!(unrestricted_once, ["-u"]);
+        snapshot_test!(unrestricted_twice, ["-u", "-u"]);
+        snapshot_test!(unrestricted_twice_in_single_flag, ["-uu"]);
         snapshot_test!(
             all_printer_opts_before_args,
             [
@@ -897,24 +913,50 @@ mod tests {
                 "--list-themes",
             ]
         );
+        snapshot_test!(
+            override_options,
+            ["--theme", "ayu-dark", "--theme", "OneHalfDark"]
+        );
 
-        #[test]
-        fn invalid_option() {
-            for args in [
-                &["--min-context", "foo"][..],
-                &["--max-context", "foo"][..],
-                &["--term-width", "foo"][..],
-                &["--term-width", "1"][..],
-                &["--tab", "foo"][..],
-                &["--printer", "syntect", "--custom-assets"][..],
-                &["--printer", "bat", "--background"][..],
-                &["--printer", "bat", "--ascii-lines"][..],
-            ] {
-                let mat = command().get_matches_from(args);
-                assert!(run(mat).is_err(), "args: {:?}", args);
-            }
+        macro_rules! snapshot_error_test {
+            ($name:ident, $args:expr) => {
+                #[test]
+                fn $name() {
+                    use std::fmt::Write;
+                    let mut settings = insta::Settings::clone_current();
+                    settings.set_snapshot_path(SNAPSHOT_DIR);
+                    settings.bind(|| {
+                        let cmd = command();
+                        let mat = cmd.try_get_matches_from($args).unwrap();
+                        let err = run(mat).unwrap_err();
+                        let mut msg = format!("{err}");
+                        for err in err.chain().skip(1) {
+                            write!(msg, " -> {err}").unwrap();
+                        }
+                        insta::assert_debug_snapshot!(msg);
+                    });
+                }
+            };
         }
 
+        snapshot_error_test!(invalid_min_context, ["--min-context", "foo"]);
+        snapshot_error_test!(invalid_max_context, ["--max-context", "foo"]);
+        snapshot_error_test!(invalid_term_width, ["--term-width", "foo"]);
+        snapshot_error_test!(term_width_too_small, ["--term-width", "1"]);
+        snapshot_error_test!(invalid_tab_width, ["--tab", "foo"]);
+        snapshot_error_test!(
+            invalid_opt_for_syntect,
+            ["--printer", "syntect", "--custom-assets"]
+        );
+        snapshot_error_test!(
+            bat_doesnt_support_background,
+            ["--printer", "bat", "--background"]
+        );
+        snapshot_error_test!(
+            bat_doesnt_support_ascii_lines,
+            ["--printer", "bat", "--ascii-lines"]
+        );
+
         #[test]
         fn arg_parser_debug_assert() {
             command().debug_assert();
@@ -944,7 +986,7 @@ mod tests {
                     let mut settings = insta::Settings::clone_current();
                     settings.set_snapshot_path(SNAPSHOT_DIR);
                     settings.bind(|| {
-                        let mat = command().get_matches_from($args);
+                        let mat = command().try_get_matches_from($args).unwrap();
                         let min_ctx = mat
                             .get_one::<String>("min-context")
                             .unwrap()
@@ -1022,6 +1064,37 @@ mod tests {
             bool_short_flags,
             ["-i", "-S", "-F", "-w", "-L", "-U", "-.", "-x", "-P", "pat", "dir"]
         );
+        snapshot_test!(max_filesize, ["--max-filesize", "100M"]);
+        snapshot_test!(unrestricted_once, ["-u"]);
+        snapshot_test!(unrestricted_twice, ["-u", "-u"]);
+
+        macro_rules! snapshot_error_test {
+            ($name:ident, $args:expr) => {
+                #[test]
+                fn $name() {
+                    use std::fmt::Write;
+                    let mut settings = insta::Settings::clone_current();
+                    settings.set_snapshot_path(SNAPSHOT_DIR);
+                    settings.bind(|| {
+                        let mat = command().try_get_matches_from($args).unwrap();
+                        let err = build_ripgrep_config(3, 6, &mat).unwrap_err();
+                        let mut msg = format!("{err}");
+                        for err in err.chain().skip(1) {
+                            write!(msg, " -> {err}").unwrap();
+                        }
+                        insta::assert_debug_snapshot!(msg);
+                    });
+                }
+            };
+        }
+
+        snapshot_error_test!(max_count_parse_error, ["--max-count", "foo"]);
+        snapshot_error_test!(max_depth_parse_error, ["--max-depth", "foo"]);
+        snapshot_error_test!(max_filesize_parse_error, ["--max-filesize", "foo"]);
+        snapshot_error_test!(regex_size_limit_parse_error, ["--regex-size-limit", "foo"]);
+        snapshot_error_test!(dfa_size_limit_parse_error, ["--dfa-size-limit", "foo"]);
+        snapshot_error_test!(too_many_u_flags_mutiple, ["-u", "-u", "-u"]);
+        snapshot_error_test!(too_many_u_flags_single, ["-uuu"]);
     }
 
     #[test]
