@@ -1,3 +1,4 @@
+use crate::broken_pipe::IgnoreBrokenPipe as _;
 use crate::chunk::{File, Line};
 use crate::printer::{Printer, PrinterOptions, TermColorSupport, TextWrapMode};
 use ansi_colours::ansi256_from_rgb;
@@ -6,7 +7,6 @@ use flate2::read::ZlibDecoder;
 use memchr::{memchr_iter, Memchr};
 use std::cmp;
 use std::ffi::OsStr;
-use std::fmt;
 use std::io::{self, Stdout, StdoutLock, Write};
 use std::ops::{Deref, DerefMut};
 use std::path::Path;
@@ -32,14 +32,16 @@ fn load_syntax_set() -> Result<SyntaxSet> {
     Ok(bincode::deserialize_from(SYNTAX_SET_BIN)?)
 }
 
-pub trait LockableWrite<'a> {
-    type Locked: Write;
-    fn lock(&'a self) -> Self::Locked;
+pub trait WriteOnLocked {
+    type Locked<'a>: Write
+    where
+        Self: 'a;
+    fn lock(&self) -> Self::Locked<'_>;
 }
 
-impl<'a> LockableWrite<'a> for Stdout {
-    type Locked = StdoutLock<'a>;
-    fn lock(&'a self) -> Self::Locked {
+impl WriteOnLocked for Stdout {
+    type Locked<'a> = StdoutLock<'a>;
+    fn lock(&self) -> Self::Locked<'_> {
         self.lock()
     }
 }
@@ -54,8 +56,6 @@ fn list_themes_with_syntaxes<W: Write>(
     opts: &PrinterOptions<'_>,
     syntaxes: &SyntaxSet,
 ) -> Result<()> {
-    use crate::broken_pipe::IgnoreBrokenPipe;
-
     let themes = {
         let mut m = load_bat_themes()?.themes;
         m.extend(ThemeSet::load_defaults().themes);
@@ -92,31 +92,6 @@ fn num_digits(n: u64) -> u16 {
     (n as f64).log10() as u16 + 1
 }
 
-#[derive(Debug)]
-pub struct PrintError {
-    message: String,
-}
-
-impl PrintError {
-    fn new<S: Into<String>>(msg: S) -> Self {
-        Self {
-            message: msg.into(),
-        }
-    }
-}
-
-impl std::error::Error for PrintError {}
-
-impl fmt::Display for PrintError {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(
-            f,
-            "Error while printing output with syntect: {}",
-            &self.message
-        )
-    }
-}
-
 #[derive(Debug)]
 struct Token<'line> {
     style: Style,
@@ -270,15 +245,6 @@ fn weak_blend_fg_color(mut fg: Color, bg: Color) -> Color {
     blend_fg_color(fg, bg)
 }
 
-#[inline]
-fn diff_u8(x: u8, y: u8) -> u8 {
-    if x > y {
-        x - y
-    } else {
-        y - x
-    }
-}
-
 #[derive(Debug)]
 struct Palette {
     foreground: Color,
@@ -309,7 +275,7 @@ impl Palette {
         b: 0,
         a: 0,
     };
-    const ANSI16: Palette = Palette {
+    const ANSI16: Self = Self {
         foreground: Self::NO_COLOR,
         background: Self::NO_COLOR,
         match_bg: Self::NO_COLOR,
@@ -343,7 +309,7 @@ impl Palette {
                 let avg_fg = color_average(foreground);
                 let avg_bg = color_average(background);
                 // Choose foreground or background looking at distance
-                if diff_u8(avg_fg, avg) > diff_u8(avg_bg, avg) {
+                if avg_fg.abs_diff(avg) > avg_bg.abs_diff(avg) {
                     foreground
                 } else {
                     background
@@ -991,8 +957,7 @@ fn load_themes(name: Option<&str>) -> Result<ThemeSet> {
             if defaults.themes.contains_key(name) {
                 Ok(defaults)
             } else {
-                let msg = format!("Unknown theme '{}'. See --list-themes output", name);
-                Err(PrintError::new(msg).into())
+                anyhow::bail!("Unknown theme '{}'. See --list-themes output", name)
             }
         }
     }
@@ -1024,10 +989,7 @@ impl Clone for SyntectAssets {
     }
 }
 
-pub struct SyntectPrinter<'main, W>
-where
-    for<'a> W: LockableWrite<'a>,
-{
+pub struct SyntectPrinter<'main, W> {
     writer: W, // Protected with mutex because it should print file by file
     syntaxes: SyntaxSet,
     themes: ThemeSet,
@@ -1040,10 +1002,7 @@ impl<'main> SyntectPrinter<'main, Stdout> {
     }
 }
 
-impl<'main, W> SyntectPrinter<'main, W>
-where
-    for<'a> W: LockableWrite<'a>,
-{
+impl<'main, W> SyntectPrinter<'main, W> {
     pub fn new(writer: W, opts: PrinterOptions<'main>) -> Result<Self> {
         Ok(Self {
             writer,
@@ -1158,13 +1117,8 @@ where
     }
 }
 
-impl<'main, W> Printer for SyntectPrinter<'main, W>
-where
-    for<'a> W: LockableWrite<'a>,
-{
+impl<'main, W: WriteOnLocked> Printer for SyntectPrinter<'main, W> {
     fn print(&self, file: File) -> Result<()> {
-        use crate::broken_pipe::IgnoreBrokenPipe;
-
         if file.chunks.is_empty() || file.line_matches.is_empty() {
             return Ok(());
         }
@@ -1211,9 +1165,9 @@ mod tests {
 
     #[derive(Default)]
     struct DummyStdout(RefCell<Vec<u8>>);
-    impl<'a> LockableWrite<'a> for DummyStdout {
-        type Locked = DummyStdoutLock<'a>;
-        fn lock(&'a self) -> Self::Locked {
+    impl WriteOnLocked for DummyStdout {
+        type Locked<'a> = DummyStdoutLock<'a>;
+        fn lock(&self) -> Self::Locked<'_> {
             DummyStdoutLock(self.0.borrow_mut())
         }
     }
@@ -1572,9 +1526,9 @@ mod tests {
     }
 
     struct ErrorStdout(io::ErrorKind);
-    impl<'a> LockableWrite<'a> for ErrorStdout {
-        type Locked = ErrorStdoutLock;
-        fn lock(&'a self) -> Self::Locked {
+    impl WriteOnLocked for ErrorStdout {
+        type Locked<'a> = ErrorStdoutLock;
+        fn lock(&self) -> Self::Locked<'_> {
             ErrorStdoutLock(self.0)
         }
     }
